@@ -30,6 +30,11 @@
 #include "folder.h"
 #include "import_utils.h"
 #include "umlscene.h"
+#include "umlobjectnamewidget.h"
+#include "umlpackagewidget.h"
+#include "umlstereotypewidget.h"
+#include "umlartifacttypewidget.h"
+#include "visibilityenumwidget.h"
 
 // kde includes
 #include <klocale.h>
@@ -49,15 +54,18 @@
 
 ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
   : DialogPageBase(parent),
-    m_pObject(o), m_pWidget(0), m_pInstanceWidget(0), m_pUmldoc(d)
+    m_pObject(o),
+    m_pWidget(0),
+    m_pInstanceWidget(0),
+    m_pUmldoc(d),
+    m_stereotypeWidget(0),
+    m_visibilityEnumWidget(0)
 {
     if (!m_pObject) {
         uWarning() << "Given UMLObject is NULL.";
         return;
     }
 
-    int margin = fontMetrics().height();
-
     setMinimumSize(310, 330);
     QVBoxLayout * topLayout = new QVBoxLayout(this);
     topLayout->setSpacing(6);
@@ -68,31 +76,19 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     QGridLayout * m_pNameLayout = new QGridLayout();
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 4);
-    m_pNameL = new QLabel(this);
-    m_pNameL->setText(name);
-    m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
-    m_pClassNameLE = new KLineEdit(this);
-    m_pNameLayout->addWidget(m_pClassNameLE, 0, 1);
-    m_pClassNameLE->setFocus();
-    m_pNameL->setBuddy(m_pClassNameLE);
+    m_nameWidget = new UMLObjectNameWidget(name, m_pObject->name());
+    m_nameWidget->addToLayout(m_pNameLayout, 0);
 
-    m_pStereoTypeCB = 0;
-    m_pPackageLE = 0;
     m_pAbstractCB = 0;
     m_pDeconCB = 0;
 
-    m_pStereoTypeL = new QLabel(i18n("&Stereotype name:"), this);
-    m_pNameLayout->addWidget(m_pStereoTypeL, 1, 0);
-
-    m_pStereoTypeCB = new KComboBox(true, this);
-    m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
-
-    m_pStereoTypeCB->setItemText(m_pStereoTypeCB->currentIndex(), m_pObject->stereotype());
-    m_pStereoTypeL->setBuddy(m_pStereoTypeCB);
-
-    if (t == UMLObject::ot_Interface || t == UMLObject::ot_Datatype || t == UMLObject::ot_Enum) {
-        m_pStereoTypeCB->setEditable(false);
+    if (t != UMLObject::ot_Stereotype) {
+        m_stereotypeWidget = new UMLStereotypeWidget(m_pObject);
+        if (t == UMLObject::ot_Interface || t == UMLObject::ot_Datatype || t == UMLObject::ot_Enum) {
+            m_stereotypeWidget->setEditable(false);
+        }
+        m_stereotypeWidget->addToLayout(m_pNameLayout, 1);
     }
 
     int row = 2;
@@ -106,32 +102,8 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     }
 
     if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface) {
-        m_pPackageL = new QLabel(i18n("Package path:"), this);
-        m_pNameLayout->addWidget(m_pPackageL, row, 0);
-
-        m_pPackageCB = new KComboBox(this);
-        m_pPackageCB->setEditable(true);
-        m_pNameLayout->addWidget(m_pPackageCB, row, 1);
-
-        UMLPackageList packageList = m_pUmldoc->packages();
-        QStringList packages;
-        foreach(UMLPackage* package, packageList) {
-            packages << package->name();
-        }
-        packages.sort();
-        m_pPackageCB->insertItems(-1, packages);
-        QString packagePath = m_pObject->package();
-        UMLPackage* parentPackage = m_pObject->umlPackage();
-
-        UMLPackage* folderLogicalView =
-                static_cast<UMLPackage*>(m_pUmldoc->rootFolder(Uml::ModelType::Logical));
-        if (parentPackage == NULL ||
-             parentPackage == folderLogicalView) {
-            m_pPackageCB->setEditText(QString());
-        }
-        else {
-            m_pPackageCB->setEditText(packagePath);
-        }
+        m_packageWidget = new UMLPackageWidget(m_pObject);
+        m_packageWidget->addToLayout(m_pNameLayout, row);
         ++row;
     }
 
@@ -156,86 +128,27 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     }
 
     if (t == UMLObject::ot_Artifact) {
-        // setup artifact draw as
-        m_pDrawAsGB = new QGroupBox(i18n("Draw As"), this);
-        QHBoxLayout* drawAsLayout = new QHBoxLayout(m_pDrawAsGB);
-        drawAsLayout->setMargin(margin);
-
-        m_pDefaultRB = new QRadioButton(i18nc("draw as default", "&Default"), m_pDrawAsGB);
-        drawAsLayout->addWidget(m_pDefaultRB);
-
-        m_pFileRB = new QRadioButton(i18n("&File"), m_pDrawAsGB);
-        drawAsLayout->addWidget(m_pFileRB);
-
-        m_pLibraryRB = new QRadioButton(i18n("&Library"), m_pDrawAsGB);
-        drawAsLayout->addWidget(m_pLibraryRB);
-
-        m_pTableRB = new QRadioButton(i18n("&Table"), m_pDrawAsGB);
-        drawAsLayout->addWidget(m_pTableRB);
-
-        topLayout->addWidget(m_pDrawAsGB);
-
-        UMLArtifact::Draw_Type drawAs = (static_cast<UMLArtifact*>(o))->getDrawAsType();
-        if (drawAs == UMLArtifact::file) {
-            m_pFileRB->setChecked(true);
-        } else if (drawAs == UMLArtifact::library) {
-            m_pLibraryRB->setChecked(true);
-        } else if (drawAs == UMLArtifact::table) {
-            m_pTableRB->setChecked(true);
-        } else {
-            m_pDefaultRB->setChecked(true);
-        }
+        m_artifactTypeWidget = new UMLArtifactTypeWidget(static_cast<UMLArtifact*>(o));
+        m_artifactTypeWidget->addToLayout(topLayout);
     }
 
     // setup scope
-    m_pButtonGB = new QGroupBox(i18n("Visibility"), this);
-    QHBoxLayout * scopeLayout = new QHBoxLayout(m_pButtonGB);
-    scopeLayout->setMargin(margin);
-
-    m_pPublicRB = new QRadioButton(i18nc("public visibility", "P&ublic"), m_pButtonGB);
-    scopeLayout->addWidget(m_pPublicRB);
-
-    m_pPrivateRB = new QRadioButton(i18nc("private visibility", "P&rivate"), m_pButtonGB);
-    scopeLayout->addWidget(m_pPrivateRB);
-
-    m_pProtectedRB = new QRadioButton(i18nc("protected visibility", "Pro&tected"), m_pButtonGB);
-    scopeLayout->addWidget(m_pProtectedRB);
-    topLayout->addWidget(m_pButtonGB);
-
-    m_pImplementationRB = new QRadioButton(i18n("Imple&mentation"), m_pButtonGB);
-    scopeLayout->addWidget(m_pImplementationRB);
-    topLayout->addWidget(m_pButtonGB);
+    if (t != UMLObject::ot_Stereotype) {
+        m_visibilityEnumWidget = new VisibilityEnumWidget(m_pObject, this);
+        m_visibilityEnumWidget->addToLayout(topLayout);
+    }
 
     m_docWidget = new DocumentationWidget(m_pObject, this);
     topLayout->addWidget(m_docWidget);
-
-    // setup fields
-    m_pClassNameLE->setText(m_pObject->name());
-
-    switch (m_pObject->visibility()) {
-    case Uml::Visibility::Public:
-        m_pPublicRB->setChecked(true);
-        break;
-    case Uml::Visibility::Private:
-        m_pPrivateRB->setChecked(true);
-        break;
-    case Uml::Visibility::Protected:
-        m_pProtectedRB->setChecked(true);
-        break;
-    default:
-        m_pImplementationRB->setChecked(true);
-        break;
-    }
-
-    // manage stereotypes
-    m_pStereoTypeCB->setDuplicatesEnabled(false);  // only allow one of each type in box
-    m_pStereoTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
-    Dialog_Utils::insertStereotypesSorted(m_pStereoTypeCB, m_pObject->stereotype());
 }
 
 ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
   : DialogPageBase(parent),
-    m_pObject(0), m_pWidget(o), m_pInstanceWidget(0), m_pUmldoc(d)
+    m_pObject(0),
+    m_pWidget(o),
+    m_pInstanceWidget(0),
+    m_pUmldoc(d),
+    m_visibilityEnumWidget(0)
 {
     if (!m_pWidget) {
         uWarning() << "Given ObjectWidget is NULL.";
@@ -253,21 +166,13 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     QGridLayout * m_pNameLayout = new QGridLayout();
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 4);
-    m_pNameL = new QLabel(this);
-    m_pNameL->setText(i18n("Class name:"));
-    m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
-    m_pClassNameLE = new KLineEdit(this);
-    m_pClassNameLE->setText(m_pWidget->name());
-    m_pNameLayout->addWidget(m_pClassNameLE, 0, 1);
+    m_nameWidget = new UMLObjectNameWidget(i18n("Class name:"), m_pWidget->name());
+    m_nameWidget->addToLayout(m_pNameLayout, 0);
 
-    m_pInstanceL = new QLabel(this);
-    m_pInstanceL->setText(i18n("Instance name:"));
-    m_pNameLayout->addWidget(m_pInstanceL, 1, 0);
+    m_instanceNameWidget = new UMLObjectNameWidget(i18n("Instance name:"), m_pWidget->instanceName());
+    m_instanceNameWidget->addToLayout(m_pNameLayout, 1);
 
-    m_pInstanceLE = new KLineEdit(this);
-    m_pInstanceLE->setText(m_pWidget->instanceName());
-    m_pNameLayout->addWidget(m_pInstanceLE, 1, 1);
     UMLView *view = UMLApp::app()->currentView();
 
     m_pDrawActorCB = new QCheckBox(i18n("Draw as actor"), this);
@@ -295,7 +200,11 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
 
 ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
   : DialogPageBase(parent),
-    m_pObject(0), m_pWidget(0), m_pInstanceWidget(widget), m_pUmldoc(d)
+    m_pObject(0),
+    m_pWidget(0),
+    m_pInstanceWidget(widget),
+    m_pUmldoc(d),
+    m_visibilityEnumWidget(0)
 {
     m_pDeconCB = 0;
     m_pMultiCB = 0;
@@ -308,36 +217,18 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLWidget* widget
     QGridLayout* m_pNameLayout = new QGridLayout();
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 3, 2);
-    m_pNameL = new QLabel(this);
-    if (widget->baseType() == WidgetBase::wt_Component) {
-        m_pNameL->setText(i18n("Component name:"));
-    } else if (widget->baseType() == WidgetBase::wt_Node) {
-        m_pNameL->setText(i18n("Node name:"));
-    } else {
-        uWarning() << "ClassGenPage called on unknown widget type";
+
+    QString typeName = UMLWidget::toI18nString(widget->baseType());
+    m_nameWidget = new UMLObjectNameWidget(typeName, widget->name());
+    m_nameWidget->addToLayout(m_pNameLayout, 0);
+
+    if (widget->umlObject()) {
+        m_stereotypeWidget = new UMLStereotypeWidget(widget->umlObject());
+        m_stereotypeWidget->addToLayout(m_pNameLayout, 1);
     }
-    m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
-    m_pClassNameLE = new KLineEdit(this);
-    m_pClassNameLE->setText(widget->name());
-    m_pNameLayout->addWidget(m_pClassNameLE, 0, 1);
-
-    m_pStereoTypeL = new QLabel(i18n("Stereotype name:"), this);
-    m_pNameLayout->addWidget(m_pStereoTypeL, 1, 0);
-
-    m_pStereoTypeCB = new KComboBox(true, this);
-    m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
-
-    m_pStereoTypeCB->setItemText(m_pStereoTypeCB->currentIndex(), widget->umlObject()->stereotype());
-    m_pStereoTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
-
-    m_pInstanceL = new QLabel(this);
-    m_pInstanceL->setText(i18n("Instance name:"));
-    m_pNameLayout->addWidget(m_pInstanceL, 2, 0);
-
-    m_pInstanceLE = new KLineEdit(this);
-    m_pInstanceLE->setText(widget->instanceName());
-    m_pNameLayout->addWidget(m_pInstanceLE, 2, 1);
+    m_instanceNameWidget = new UMLObjectNameWidget(i18n("Instance name:"), widget->instanceName());
+    m_instanceNameWidget->addToLayout(m_pNameLayout, 2);
 
     m_docWidget = new DocumentationWidget(widget, this);
     topLayout->addWidget(m_docWidget);
@@ -351,32 +242,20 @@ ClassGeneralPage::~ClassGeneralPage()
  * Will move information from the dialog into the object.
  * Call when the ok or apply button is pressed.
  */
-void ClassGeneralPage::updateObject()
+void ClassGeneralPage::apply()
 {
+    QString name = m_nameWidget->text();
     m_docWidget->apply();
 
     if (m_pObject) {
-        QString name = m_pClassNameLE->text();
 
-        if (m_pStereoTypeCB) {
-            m_pObject->setStereotype(m_pStereoTypeCB->currentText());
+        if (m_stereotypeWidget) {
+            m_stereotypeWidget->apply();
         }
 
         UMLObject::ObjectType t = m_pObject->baseType();
         if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface) {
-            QString packageName = m_pPackageCB->currentText().trimmed();
-            UMLObject* newPackage = NULL;
-
-            if (!packageName.isEmpty()) {
-                if ((newPackage = m_pUmldoc->findUMLObject(packageName, UMLObject::ot_Package)) == NULL) {
-                    newPackage = Import_Utils::createUMLObject(UMLObject::ot_Package, packageName);
-                }
-            } else {
-                newPackage = m_pUmldoc->rootFolder(Uml::ModelType::Logical);
-            }
-
-            // adjust list view items
-            Model_Utils::treeViewMoveObjectTo(newPackage, m_pObject);
+            m_packageWidget->apply();
         }
 
         if (m_pAbstractCB) {
@@ -388,41 +267,27 @@ void ClassGeneralPage::updateObject()
         if (o && m_pObject != o) {
              KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
                                 i18n("Name is Not Unique"), 0);
-             m_pClassNameLE->setText(m_pObject->name());
+             m_nameWidget->reset();
         } else {
              m_pObject->setName(name);
         }
 
-        Uml::Visibility::Enum s = Uml::Visibility::Implementation;
-        if (m_pPublicRB->isChecked())
-            s = Uml::Visibility::Public;
-        else if (m_pPrivateRB->isChecked())
-            s = Uml::Visibility::Private;
-        else if (m_pProtectedRB->isChecked())
-            s = Uml::Visibility::Protected;
-        m_pObject->setVisibility(s);
+        if (t != UMLObject::ot_Stereotype) {
+            if (m_visibilityEnumWidget)
+                m_visibilityEnumWidget->apply();
+        }
 
         if (m_pObject->baseType() == UMLObject::ot_Component) {
             (static_cast<UMLComponent*>(m_pObject))->setExecutable(m_pExecutableCB->isChecked());
         }
 
         if (m_pObject->baseType() == UMLObject::ot_Artifact) {
-            UMLArtifact::Draw_Type drawAsType;
-            if (m_pFileRB->isChecked()) {
-                drawAsType = UMLArtifact::file;
-            } else if (m_pLibraryRB->isChecked()) {
-                drawAsType = UMLArtifact::library;
-            } else if (m_pTableRB->isChecked()) {
-                drawAsType = UMLArtifact::table;
-            } else {
-                drawAsType = UMLArtifact::defaultDraw;
-            }
-            (static_cast<UMLArtifact*>(m_pObject))->setDrawAsType(drawAsType);
+            m_artifactTypeWidget->apply();
             m_pObject->emitModified();
         }
     } // end if m_pObject
     else if (m_pWidget) {
-        m_pWidget->setInstanceName(m_pInstanceLE->text());
+        m_pWidget->setInstanceName(m_instanceNameWidget->text());
         if (m_pMultiCB) {
             m_pWidget->setMultipleInstance(m_pMultiCB->isChecked());
         }
@@ -430,28 +295,36 @@ void ClassGeneralPage::updateObject()
         if (m_pDeconCB) {
             m_pWidget->setShowDestruction(m_pDeconCB->isChecked());
         }
-        QString name = m_pClassNameLE->text();
         UMLObject * o = m_pWidget->umlObject();
+        if (!o) {
+            uError() << "UML object of widget is zero.";
+            return;
+        }
         UMLObject * old = m_pUmldoc->findUMLObject(name);
         if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
                                i18n("Name is Not Unique"), 0);
+            m_nameWidget->reset();
         } else {
             o->setName(name);
         }
     } // end if m_pWidget
     else if (m_pInstanceWidget) {
-        m_pInstanceWidget->setInstanceName(m_pInstanceLE->text());
-        QString name = m_pClassNameLE->text();
+        m_pInstanceWidget->setInstanceName(m_instanceNameWidget->text());
         UMLObject* o = m_pInstanceWidget->umlObject();
+        if (!o) {
+            uError() << "UML object of instance widget is zero.";
+            return;
+        }
+
         UMLObject* old = m_pUmldoc->findUMLObject(name);
         if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
                                i18n("Name is Not Unique"), 0);
+            m_nameWidget->reset();
         } else {
             o->setName(name);
         }
-        o->setStereotype(m_pStereoTypeCB->currentText());
     } // end if m_pInstanceWidget
 }
 
