@@ -13,6 +13,7 @@
 
 // local includes
 #include "activitypage.h"
+#include "documentationwidget.h"
 #include "umlview.h"
 #include "statewidget.h"
 #include "dialog_utils.h"
@@ -23,7 +24,6 @@
 #include <klineedit.h>
 #include <klocale.h>
 #include <kfontdialog.h>
-#include <ktextedit.h>
 
 // qt includes
 #include <QFrame>
@@ -36,7 +36,7 @@
  * Constructor.
  */
 StateDialog::StateDialog(QWidget * parent, StateWidget * pWidget)
-  : DialogBase(parent),
+  : MultiPageDialogBase(parent),
     m_pActivityPage(0),
     m_pStateWidget(pWidget),
     m_bChangesMade(false)
@@ -88,7 +88,7 @@ void StateDialog::applyPage(KPageWidgetItem*item)
     m_bChangesMade = true;
     if (item == pageGeneral) {
         m_pStateWidget->setName(m_GenPageWidgets.nameLE->text());
-        m_pStateWidget->setDocumentation(m_GenPageWidgets.docMLE->toPlainText());
+        m_GenPageWidgets.docWidget->apply();
     }
     else if (item == pageActivity) {
         if (m_pActivityPage) {
@@ -96,10 +96,10 @@ void StateDialog::applyPage(KPageWidgetItem*item)
         }
     }
     else if (item == pageStyle) {
-        saveStylePageData(m_pStateWidget);
+        applyStylePage();
     }
     else if (item == pageFont) {
-        saveFontPageData(m_pStateWidget);
+        applyFontPage(m_pStateWidget);
     }
 }
 
@@ -111,10 +111,8 @@ void StateDialog::setupGeneralPage()
     StateWidget::StateType type = m_pStateWidget->stateType();
 
     KVBox * page = new KVBox();
-    pageGeneral = new KPageWidgetItem(page, i18nc("general page", "General"));
-    pageGeneral->setHeader(i18n("General Properties"));
-    pageGeneral->setIcon(Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_General));
-    addPage(pageGeneral);
+    pageGeneral = createPage(i18nc("general page", "General"), i18n("General Properties"),
+                             Icon_Utils::it_Properties_General, page);
 
     m_GenPageWidgets.generalGB = new QGroupBox(i18n("Properties"), (QWidget *)page);
 
@@ -164,15 +162,8 @@ void StateDialog::setupGeneralPage()
                                     m_GenPageWidgets.nameL, i18n("State name:"),
                                     m_GenPageWidgets.nameLE);
 
-    m_GenPageWidgets.docGB = new QGroupBox(i18n("Documentation"), (QWidget *)page);
-
-    QHBoxLayout * docLayout = new QHBoxLayout(m_GenPageWidgets.docGB);
-    docLayout->setSpacing(spacingHint());
-    docLayout->setMargin(fontMetrics().height());
-
-    m_GenPageWidgets.docMLE = new KTextEdit(m_GenPageWidgets.docGB);
-    m_GenPageWidgets.docMLE->setText(m_pStateWidget->documentation());
-    docLayout->addWidget(m_GenPageWidgets.docMLE);
+    m_GenPageWidgets.docWidget = new DocumentationWidget(m_pStateWidget, (QWidget *)page);
+    generalLayout->addWidget(m_GenPageWidgets.docWidget, 2, 0, 1, 2);
 
     if (type != StateWidget::Normal) {
         m_GenPageWidgets.nameLE->setEnabled(false);
@@ -186,15 +177,9 @@ void StateDialog::setupGeneralPage()
  */
 void StateDialog::setupActivityPage()
 {
-    QFrame * activityPage = new QFrame();
-    pageActivity = new KPageWidgetItem(activityPage, i18n("Activities"));
-    pageActivity->setHeader(i18n("Activities"));
-    pageActivity->setIcon(Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Activities));
-    addPage(pageActivity);
-
-    QHBoxLayout * activityLayout = new QHBoxLayout(activityPage);
-    m_pActivityPage = new ActivityPage(activityPage, m_pStateWidget);
-    activityLayout->addWidget(m_pActivityPage);
+    m_pActivityPage = new ActivityPage(0, m_pStateWidget);
+    pageActivity = createPage(i18n("Activities"), i18n("Activities"),
+                              Icon_Utils::it_Properties_Activities, m_pActivityPage);
 }
 
 #include "statedialog.moc"
