@@ -18,6 +18,8 @@
 #include "template.h"
 #include "umldoc.h"
 #include "uml.h"
+#include "umlstereotypewidget.h"
+#include "visibilityenumwidget.h"
 #include "dialog_utils.h"
 #include "object_factory.h"
 #include "import_utils.h"
@@ -40,13 +42,9 @@
 #include <QVBoxLayout>
 
 UMLAttributeDialog::UMLAttributeDialog(QWidget * pParent, UMLAttribute * pAttribute)
-        : KDialog(pParent)
+  : SinglePageDialogBase(pParent)
 {
     setCaption(i18n("Attribute Properties"));
-    setButtons(Help | Ok | Cancel);
-    setDefaultButton(Ok);
-    setModal(true);
-    showButtonSeparator(true);
     m_pAttribute = pAttribute;
     setupDialog();
 }
@@ -86,50 +84,16 @@ void UMLAttributeDialog::setupDialog()
                                     m_pInitialL, i18n("&Initial value:"),
                                     m_pInitialLE, m_pAttribute->getInitialValue());
 
-    Dialog_Utils::makeLabeledEditField(valuesLayout, 3,
-                                    m_pStereoTypeL, i18n("Stereotype name:"),
-                                    m_pStereoTypeLE, m_pAttribute->stereotype());
+    m_stereotypeWidget = new UMLStereotypeWidget(m_pAttribute);
+    m_stereotypeWidget->addToLayout(valuesLayout, 3);
 
     m_pStaticCB = new QCheckBox(i18n("Classifier &scope (\"static\")"), m_pValuesGB);
     m_pStaticCB->setChecked(m_pAttribute->isStatic());
     valuesLayout->addWidget(m_pStaticCB, 4, 0);
 
     mainLayout->addWidget(m_pValuesGB);
-
-    m_pScopeGB = new QGroupBox(i18n("Visibility"), frame);
-    QHBoxLayout * scopeLayout = new QHBoxLayout(m_pScopeGB);
-    scopeLayout->setMargin(margin);
-
-    m_pPublicRB = new QRadioButton(i18nc("access control public", "&Public"), m_pScopeGB);
-    scopeLayout->addWidget(m_pPublicRB);
-
-    m_pPrivateRB = new QRadioButton(i18nc("access control private", "P&rivate"), m_pScopeGB);
-    scopeLayout->addWidget(m_pPrivateRB);
-
-    m_pProtectedRB = new QRadioButton(i18nc("access control protected", "Prot&ected"), m_pScopeGB);
-    scopeLayout->addWidget(m_pProtectedRB);
-
-    m_pImplementationRB = new QRadioButton(i18n("I&mplementation"), m_pScopeGB);
-    scopeLayout->addWidget(m_pImplementationRB);
-
-    mainLayout->addWidget(m_pScopeGB);
-
-    switch (m_pAttribute->visibility()) {
-    case Uml::Visibility::Public:
-        m_pPublicRB->setChecked(true);
-        break;
-    case Uml::Visibility::Private:
-        m_pPrivateRB->setChecked(true);
-        break;
-    case Uml::Visibility::Protected:
-        m_pProtectedRB->setChecked(true);
-        break;
-    case Uml::Visibility::Implementation:
-        m_pImplementationRB->setChecked(true);
-        break;
-    default:
-        break;
-    }
+    m_visibilityEnumWidget = new VisibilityEnumWidget(m_pAttribute, this);
+    m_visibilityEnumWidget->addToLayout(mainLayout);
 
     m_pTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
     m_pTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
@@ -143,8 +107,6 @@ void UMLAttributeDialog::setupDialog()
     m_pNameLE->setFocus();
     connect(m_pNameLE, SIGNAL(textChanged(QString)), SLOT(slotNameChanged(QString)));
     slotNameChanged(m_pNameLE->text());
-    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
 }
 
 void UMLAttributeDialog::slotNameChanged(const QString &_text)
@@ -174,22 +136,15 @@ bool UMLAttributeDialog::apply()
         return false;
     }
     m_pAttribute->setName(name);
-    Uml::Visibility::Enum scope = Uml::Visibility::Protected;
-    if (m_pPublicRB->isChecked()) {
-        scope = Uml::Visibility::Public;
-    } else if (m_pPrivateRB->isChecked()) {
-        scope = Uml::Visibility::Private;
-    } else if (m_pImplementationRB->isChecked()) {
-        scope = Uml::Visibility::Implementation;
-    }
-    m_pAttribute->setVisibility(scope);
+    m_visibilityEnumWidget->apply();
+
     // Set the scope as the default in the option state
     Settings::OptionState optionState = Settings::optionState();
-    optionState.classState.defaultAttributeScope = scope;
+    optionState.classState.defaultAttributeScope = m_pAttribute->visibility();
     Settings::setOptionState(optionState);
 
     m_pAttribute->setInitialValue(m_pInitialLE->text());
-    m_pAttribute->setStereotype(m_pStereoTypeLE->text());
+    m_stereotypeWidget->apply();
     m_pAttribute->setStatic(m_pStaticCB->isChecked());
 
     QString typeName = m_pTypeCB->currentText();
@@ -238,25 +193,6 @@ bool UMLAttributeDialog::apply()
     return true;
 }
 
-/**
- * I don't think this is used, but if we had an apply button
- * it would slot into here
- */
-void UMLAttributeDialog::slotApply()
-{
-    apply();
-}
-
-/**
- * Used when the OK button is clicked.  Calls apply()
- */
-void UMLAttributeDialog::slotOk()
-{
-    if (apply()) {
-        accept();
-    }
-}
-
 /**
  * Inserts @p type into the type-combobox as well as its completion object.
  * The combobox is cleared and all types together with the optional new one
