@@ -20,6 +20,7 @@
 #include "template.h"
 #include "listpopupmenu.h"
 #include "umlattributelist.h"
+#include "umlstereotypewidget.h"
 #include "classifierlistitem.h"
 #include "documentationwidget.h"
 #include "umlclassifierlistitemlist.h"
@@ -27,6 +28,7 @@
 #include "parameterpropertiesdialog.h"
 #include "stereotype.h"
 #include "uniqueid.h"
+#include "visibilityenumwidget.h"
 
 //kde includes
 #include <klineedit.h>
@@ -53,20 +55,13 @@
  * Constructor.
  */
 UMLOperationDialog::UMLOperationDialog(QWidget * parent, UMLOperation * pOperation)
-  : KDialog(parent)
+  : SinglePageDialogBase(parent)
 {
     setCaption(i18n("Operation Properties"));
-    setButtons(Help | Ok | Cancel);
-    setDefaultButton(Ok);
-    setModal(true);
-    showButtonSeparator(true);
-
     m_operation = pOperation;
     m_doc = UMLApp::app()->document();
     m_menu = 0;
     setupDialog();
-    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
 }
 
 /**
@@ -106,10 +101,8 @@ void UMLOperationDialog::setupDialog()
     genLayout->addWidget(m_pRtypeCB, 0, 3);
     m_pRtypeL->setBuddy(m_pRtypeCB);
 
-    m_pStereoTypeL = new QLabel(i18n("Stereotype name:"), m_pGenGB);
-    genLayout->addWidget(m_pStereoTypeL, 1, 0);
-    m_pStereoTypeCB = new KComboBox(true, m_pGenGB);
-    genLayout->addWidget(m_pStereoTypeCB, 1, 1);
+    m_stereotypeWidget = new UMLStereotypeWidget(m_operation);
+    m_stereotypeWidget->addToLayout(genLayout, 1);
 
     m_pAbstractCB = new QCheckBox(i18n("&Abstract operation"), m_pGenGB);
     m_pAbstractCB->setChecked(m_operation->isAbstract());
@@ -121,22 +114,7 @@ void UMLOperationDialog::setupDialog()
     m_pQueryCB->setChecked(m_operation->getConst());
     genLayout->addWidget(m_pQueryCB, 2, 2);
 
-    m_pScopeGB = new QGroupBox(i18n("Visibility"), frame);
-
-    QHBoxLayout * scopeLayout = new QHBoxLayout(m_pScopeGB);
-    scopeLayout->setMargin(margin);
-
-    m_pPublicRB = new QRadioButton(i18nc("public visibility", "P&ublic"), m_pScopeGB);
-    scopeLayout->addWidget(m_pPublicRB);
-
-    m_pPrivateRB = new QRadioButton(i18nc("private visibility", "P&rivate"), m_pScopeGB);
-    scopeLayout->addWidget(m_pPrivateRB);
-
-    m_pProtectedRB = new QRadioButton(i18nc("protected visibility", "Prot&ected"), m_pScopeGB);
-    scopeLayout->addWidget(m_pProtectedRB);
-
-    m_pImplementationRB = new QRadioButton(i18n("I&mplementation"), m_pScopeGB);
-    scopeLayout->addWidget(m_pImplementationRB);
+    m_visibilityEnumWidget = new VisibilityEnumWidget(m_operation, this);
 
     m_docWidget = new DocumentationWidget(m_operation, this);
 
@@ -178,7 +156,7 @@ void UMLOperationDialog::setupDialog()
     parmsLayout->addWidget(buttonBox);
 
     topLayout->addWidget(m_pGenGB);
-    topLayout->addWidget(m_pScopeGB);
+    topLayout->addWidget(m_visibilityEnumWidget);
     topLayout->addWidget(m_docWidget);
     topLayout->addWidget(m_pParmsGB);
 
@@ -198,29 +176,6 @@ void UMLOperationDialog::setupDialog()
         m_pParmsLW->addItem(pAtt->toString(Uml::SignatureType::SigNoVis));
     }
 
-    // set scope
-    switch (m_operation->visibility()) {
-    case Uml::Visibility::Public:
-        m_pPublicRB->setChecked(true);
-        break;
-    case Uml::Visibility::Private:
-        m_pPrivateRB->setChecked(true);
-        break;
-    case Uml::Visibility::Protected:
-        m_pProtectedRB->setChecked(true);
-        break;
-    case Uml::Visibility::Implementation:
-        m_pImplementationRB->setChecked(true);
-        break;
-    default:
-        break;
-    }
-
-    // manage stereotypes
-    m_pStereoTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
-    m_pStereoTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
-    insertStereotypesSorted(m_operation->stereotype());
-
     // setup parm list box signals
     connect(m_pUpButton, SIGNAL(clicked()), this, SLOT(slotParameterUp()));
     connect(m_pDownButton, SIGNAL(clicked()), this, SLOT(slotParameterDown()));
@@ -454,14 +409,7 @@ bool UMLOperationDialog::apply()
     }
     m_operation->setName(name);
 
-    if(m_pPublicRB->isChecked())
-      m_operation->setVisibility(Uml::Visibility::Public);
-    else if(m_pPrivateRB->isChecked())
-      m_operation->setVisibility(Uml::Visibility::Private);
-    else if (m_pProtectedRB->isChecked())
-      m_operation->setVisibility(Uml::Visibility::Protected);
-    else if (m_pImplementationRB->isChecked())
-      m_operation->setVisibility(Uml::Visibility::Implementation);
+    m_visibilityEnumWidget->apply();
 
     QString typeName = m_pRtypeCB->currentText();
     UMLTemplate *tmplParam = 0;
@@ -473,7 +421,7 @@ bool UMLOperationDialog::apply()
     else
         m_operation->setTypeName(typeName);
 
-    m_operation->setStereotype(m_pStereoTypeCB->currentText());
+    m_stereotypeWidget->apply();
 
     bool isAbstract = m_pAbstractCB->isChecked();
     m_operation->setAbstract(isAbstract);
@@ -494,22 +442,6 @@ bool UMLOperationDialog::apply()
     return true;
 }
 
-/**
- * I don't think this is used, but if we had an apply button
- * it would slot into here.
- */
-void UMLOperationDialog::slotApply()
-{
-    apply();
-}
-
-void UMLOperationDialog::slotOk()
-{
-    if (apply()) {
-        accept();
-    }
-}
-
 /**
  * Inserts @p type into the type-combobox.
  * The combobox is cleared and all types together with the optional new one
@@ -554,33 +486,4 @@ void UMLOperationDialog::insertTypesSorted(const QString& type)
     }
 }
 
-/**
- * Inserts @p stereotype into the stereotype-combobox as well as its completion object.
- * The combobox is cleared and all types together with the optional new one
- * sorted and then added again.
- * @param type   a new type to add and selected
- */
-void UMLOperationDialog::insertStereotypesSorted(const QString& type)
-{
-    QStringList types;
-    foreach (UMLStereotype* currentSt, m_doc->stereotypes()) {
-        types << currentSt->name();
-    }
-    // add the given parameter
-    if (!types.contains(type)) {
-        types << type;
-    }
-    types.sort();
-
-    m_pStereoTypeCB->clear();
-    m_pStereoTypeCB->insertItems(-1, types);
-
-    // select the given parameter
-    int currentIndex = m_pStereoTypeCB->findText(type);
-    if (currentIndex > -1) {
-        m_pStereoTypeCB->setCurrentIndex(currentIndex);
-    }
-    m_pStereoTypeCB->completionObject()->addItem(type);
-}
-
 #include "umloperationdialog.moc"
