@@ -229,13 +229,13 @@ namespace Icon_Utils {
     QPixmap MainBarIcon(IconType type);
     QPixmap UserIcon(IconType type);
 
-    KIcon DesktopIcon(IconType type);
+    QPixmap DesktopIcon(IconType type);
 
     QCursor Cursor(IconType type);
 
     QString toString(IconType type);
 
-    KIcon iconSet(Uml::DiagramType::Enum dt);
+    QPixmap iconSet(Uml::DiagramType::Enum dt);
 
 }  // namespace
 
