@@ -662,11 +662,12 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
     setPenFromSettings(painter);
     if (UMLWidget::useFillColor())
         painter->setBrush(UMLWidget::fillColor());
-    else
-        painter->setBrush(m_scene->activeView()->viewport()->palette().color(QPalette::Background));
-
+    else {
+        painter->setBrush(m_scene->backgroundColor());
+    }
     if (m_umlObject->baseType() == UMLObject::ot_Package) {
         drawAsPackage(painter, option);
+        UMLWidget::paint(painter, option, widget);
         return;
     }
     UMLClassifier *umlc = this->classifier();
@@ -676,6 +677,7 @@ void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *
     }
     if (umlc->isInterface() && visualProperty(DrawAsCircle)) {
         drawAsCircle(painter, option);
+        UMLWidget::paint(painter, option, widget);
         return;
     }
 
