@@ -99,7 +99,7 @@ void EnumWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
     if(UMLWidget::useFillColor())
         painter->setBrush(UMLWidget::fillColor());
     else
-        painter->setBrush(m_scene->activeView()->viewport()->palette().color(QPalette::Background));
+        painter->setBrush(m_scene->backgroundColor());
 
     const int w = width();
     const int h = height();
