@@ -415,7 +415,7 @@ void ObjectWidget::paintObject(QPainter *painter)
     if(UMLWidget::useFillColor())
         painter->setBrush(UMLWidget::fillColor());
     else
-        painter->setBrush(m_scene->activeView()->viewport()->palette().color(QPalette::Background));
+        painter->setBrush(m_scene->backgroundColor());
     const int w = width();
     const int h = height();
 
